summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorSlávek Banko <[email protected]>2021-08-26 03:46:34 +0200
committerSlávek Banko <[email protected]>2021-08-26 15:41:58 +0200
commit031ded8cf8bce48796f34575958d60495b3de42b (patch)
tree4357abef1c117b20b9fab37a17df6ec6d232feb6 /src
parentaf07d98a53810517eedc97f3ef6bc42670635c4d (diff)
downloadtdesshaskpass-031ded8cf8bce48796f34575958d60495b3de42b.tar.gz
tdesshaskpass-031ded8cf8bce48796f34575958d60495b3de42b.zip
Initial TDE conversion.
Signed-off-by: Slávek Banko <[email protected]>
Diffstat (limited to 'src')
-rw-r--r--src/CMakeLists.txt4
-rw-r--r--src/ksshaskpass.cpp36
2 files changed, 20 insertions, 20 deletions
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index 7e4ca6c..0c49fbb 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -19,8 +19,8 @@ tde_add_executable( ${PROJECT_NAME} AUTOMOC
SOURCES
ksshaskpass.cpp
LINK
- kdeui-shared
- kio-shared
+ tdeui-shared
+ tdeio-shared
DESTINATION ${BIN_INSTALL_DIR}
)
diff --git a/src/ksshaskpass.cpp b/src/ksshaskpass.cpp
index bad94c1..036b3dc 100644
--- a/src/ksshaskpass.cpp
+++ b/src/ksshaskpass.cpp
@@ -19,28 +19,28 @@
#include <iostream>
-#include <kwallet.h>
+#include <tdewallet.h>
#include <kpassdlg.h>
-#include <kaboutdata.h>
-#include <kapplication.h>
-#include <kcmdlineargs.h>
-#include <klocale.h>
+#include <tdeaboutdata.h>
+#include <tdeapplication.h>
+#include <tdecmdlineargs.h>
+#include <tdelocale.h>
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
{
{ "+[dialog]", I18N_NOOP( "Dialog message. Leave undefined for default message" ), 0 },
- KCmdLineLastOption
+ TDECmdLineLastOption
};
int main(int argc, char **argv)
{
- KAboutData about (
+ TDEAboutData about (
"Ksshaskpass", // appName
I18N_NOOP("Ksshaskpass"), // programName
"0.4.1", // version
- I18N_NOOP("KDE version of ssh-askpass"), // shortDescription
- KAboutData::License_GPL, // licenseType
+ I18N_NOOP("TDE version of ssh-askpass"), // shortDescription
+ TDEAboutData::License_GPL, // licenseType
"(c) 2006 Hans van Leeuwen\n(c) 2008 Armin Berres", // copyrightStatement statement
I18N_NOOP("Ksshaskpass allows you to interactively prompt users for a passphrase for ssh-add"), // text
"http://www.kde-apps.org/content/edit.php?content=50971", // homePageAddress
@@ -49,11 +49,11 @@ int main(int argc, char **argv)
about.addAuthor("Armin Berres", 0, "[email protected]");
about.addAuthor("Hans van Leeuwen", 0, "[email protected]");
- KCmdLineArgs::init(argc, argv, &about);
- KCmdLineArgs::addCmdLineOptions( options );
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::addCmdLineOptions( options );
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
- KApplication app;
+ TDEApplication app;
// Disable Session Management and DCOP. We don't need it.
@@ -76,8 +76,8 @@ int main(int argc, char **argv)
args->clear();
- // Open KWallet to see if a password was previously stored.
- KWallet::Wallet *wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet(), 0 );
+ // Open TDEWallet to see if a password was previously stored.
+ TDEWallet::Wallet *wallet = TDEWallet::Wallet::openWallet( TDEWallet::Wallet::NetworkWallet(), 0 );
if ( wallet && wallet->hasFolder(walletFolder) ) {
wallet->setFolder(walletFolder);
@@ -108,7 +108,7 @@ int main(int argc, char **argv)
password = kpd->password();
}
// If "Enable Keep" is enabled, open/create a folder in KWallet and store the password.
if (!password.isNull() && wallet && kpd->keep())
{
if ( !wallet->hasFolder( walletFolder ) ) {
@@ -123,7 +123,7 @@ int main(int argc, char **argv)
// Close the wallet if it is opened.
if (wallet) {
- KWallet::Wallet::closeWallet( KWallet::Wallet::NetworkWallet(), false );
+ TDEWallet::Wallet::closeWallet( TDEWallet::Wallet::NetworkWallet(), false );
}
// Finally return the password if one has been entered
@@ -108,7 +108,7 @@ int main(int argc, char **argv)
password = kpd->password();
}
- // If "Enable Keep" is enabled, open/create a folder in KWallet and store the password.
+ // If "Enable Keep" is enabled, open/create a folder in TDEWallet and store the password.
if (!password.isNull() && wallet && kpd->keep())
{